==> patch-2.5.5.0_5.zip: app/views/sync/sharedFiles.php <==
<?php use \Core\View;
use Helpers\Auth;
use Helpers\Url;
use Helpers\Form;
use Core\Language;
/*
*
* Copyright 2015
* ParaBlu Systems Private Limited
* All Rights Reserved
*
* NOTICE:  All information contained herein is, and remains
* the property of ParaBlu Systems Private Limited and its suppliers, if any.
* The intellectual and technical concepts contained herein are proprietary
* to ParaBlu Systems Private Limited and its suppliers and may be covered by
* Indian, US and Foreign Patents, patents in process, and are protected by
* trade secret or copyright law.
* Dissemination of this information or reproduction of this material
* is strictly forbidden unless prior written permission is obtained
* from ParaBlu Systems Private Limited.
*
* index.php
*
* @author Naveen Verma - naveenverma@parablu.com
* @version 2..5.5
* @date 17/02/2022
* @time 12:07 PM
*
*/

?>
<div class="container">
    <div class="row">
        <div class="col-lg-6">
            <ol class="breadcrumb">
              <li><h3><?=$data['title']?></h3></li>
                <!--<li><?=$data['crumb1']?></li>-->
            </ol>
        </div>
        <div class="col-lg-6 d-none">
            <?php View::renderTemplate('partials/createButton', $data)?>
        </div>
    </div>
</div>
<div class="main" ng-controller="PmsController">
    <span class="d-none currentPage"><?=''?></span>
    <span class="d-none csrf_token"><?=$data['csrf_token'];?></span>
    <div class="row profile">
        <div class="col-lg-1 col-md-1 col-sm-1">
            <?php View::renderTemplate('partials/sideBar', $data); ?>
        </div>
        <div class="col-lg-11 col-md-11 col-sm-11 ng-cloak">
            <?php if(isMobile()){ ?>
                    <ul class="nav nav-pills flex-column hide" style="border: 1px solid #EC6621;border-radius: 10px;">
                      <li class="nav-item" style="display:unset !important;"><a class="nav-link active" data-toggle="tab" data-target="#filesSharedByMe" aria-expanded="true" aria-controls="filesSharedByMe">Files Shared By Me</a></li>
                      <li class="nav-item" style="display:unset !important;"><a data-toggle="tab" class="nav-link" data-target="#filesSharedWithMe" aria-expanded="false" aria-controls="filesSharedWithMe">Files Shared With Me</a></li>
                    </ul>
            <?php } ?>
            <?php if(!isMobile()){ ?>
                    <ul class="nav nav-tabs hide" role="tablist" style="font-weight: 600;<?php if(!isMobile()){ ?>font-size: medium;<?php }else { ?> font-size: small;<?php } ?>">
                        <li role="presentation" class="nav-item"><a class="nav-link active" data-target="#filesSharedByMe" aria-controls="filesSharedByMe" role="tab" data-toggle="tab">Files Shared By Me</a></li>
                        <li role="presentation" class="nav-item"><a class="nav-link" data-target="#filesSharedWithMe" aria-controls="filesSharedWithMe" role="tab" data-toggle="tab">Files Shared With Me</a></li>
                    </ul>
            <?php } ?>
            <div class="tab-content">
                <div role="tabpanel" class="tab-pane active" id="filesSharedByMe">
                        <div class="row">
                            <div class="panel col-lg-12">
                                <div class="panel-heading hide">
                                    <h4 style="padding: 0px 0px 0px 15px;">Files Shared By Me</h4>
                                </div>
                                <div class="panel-body">
                                 <div class="row">
                                    <div class="col-lg-4">
                                        <div class="panel panel-default no-box-shadow widget-default widget-click">
                                            <!--<div class="panel-header pull-right" style="margin-right: 10px; margin-top: -11px;">
                                                <a class="btn btn-success btn-small hide" ng-click="sendMeTo('/pms/filters')"><i class="fa fa-filter" style="color: white"></i> Filters</a>
                                                <a class="btn btn-success btn-small hide" ng-click="sendMeTo('/pms/schedules')"><i class="fa fa-clock-o" style="color: white"></i> Schedules</a>
                                            </div>
                                            <hr/>-->
                                            <div class="background">
                                                <i class="fa fa-file-o"></i>
                                            </div>
                                            <div class="panel-body widget widget-body clickAble" ng-click="sendMeTo('/share/myShares')">
                                                <i class="fa fa-file-o"></i><span style="font-weight:600;"> Files Shared By Me</span><br/>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-lg-4">
                                        <div class="panel panel-default no-box-shadow widget-default widget-click">
                                            <!--<div class="panel-header pull-right" style="margin-right: 10px; margin-top: -11px;">
                                                <a class="btn btn-small btn-success pull-right hide" ng-click="sendMeTo('/pms/policyMapping/multiple')">Map policies in bulk</a>
                                            </div>
                                            <hr/>-->
                                            <div class="background">
                                                <i class="fa fa-file-o"></i>
                                            </div>
                                            <div class="panel-body widget widget-body clickAble" ng-click="sendMeTo('/share/filesSharedWithMe')">
                                                <i class="fa fa-file-o"></i><span style="font-weight:600;"> Files Shared With Me</span><br/>
                                            </div>
                                        </div>
                                    </div>
                                </div>
</div>
                            </div>
                        </div>
                </div>
                <div role="tabpanel" class="tab-pane" id="filesSharedWithMe">
                            <div class="row">
                                <div class="panel col-lg-12">
                                    <div class="panel-heading">
                                        <h4 style="padding: 0px 0px 0px 15px;">Files Shared With Me</h4>
                                    </div>
                                    <div class="panel-body">
                                       <div class="row">
                                        <div class="col-lg-4">
                                            <div class="panel panel-default no-box-shadow widget-default widget-click">
                                                <div class="panel-header pull-right" style="margin-right: 10px; margin-top: -11px;">
                                                    <a class="btn btn-success btn-small" ng-click="sendMeTo('/pms/filters')"><i class="fa fa-filter" style="color: white"></i> Filters</a>
                                                    <a class="btn btn-success btn-small d-none" ng-click="sendMeTo('/pms/cloudCredentials')"><i class="fa fa-cloud" style="color: white"></i> Cloud Credentials</a>
                                                </div>
                                                <hr/>
                                                <div class="background">
                                                    <i class="fa fa-file-powerpoint-o"></i>
                                                </div>
                                                <div class="panel-body widget widget-body clickAble" ng-click="sendMeTo('/pms/sync/policies')">
                                                    <?php if(BLUDRIVE_MODE == true){?>
                                                        <i class="fa fa-file-powerpoint-o"> BluDrive Policies</i><br/>
                                                    <a>Create, View, Edit, Clone Policies</a>
                                                    <?php } else {?>
                                                        <i class="fa fa-file-powerpoint-o"> File Sync and Share Policies</i><br/>
                                                                    <a>Create, View, Edit, Clone Policies</a>
                                                    <?php } ?>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-lg-4">
                                            <div class="panel panel-default no-box-shadow widget-default widget-click">
                                                <div class="panel-header pull-right" style="margin-right: 10px; margin-top: -11px;">
                                                    <a class="btn btn-small btn-success pull-right" ng-click="sendMeTo('/pms/sync/policyMapping/multiple')">Map policies in bulk</a>
                                                </div>
                                                <hr/>
                                                <div class="background">
                                                    <i class="fa fa-user"></i>
                                                </div>
                                                <div class="panel-body widget widget-body clickAble" ng-click="sendMeTo('/pms/sync/policyMapping/single')">
                                                    <i class="fa fa-user"> Policy Mapping</i><br/>
                                                    <?php if(BLUDRIVE_MODE == true){?>
                                                    <a>Map users to BluDrive policies</a>
                                                    <?php } else {?>
                                                    <a>Map users to Sync policies</a>
                                                    <?php } ?>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
</div>
                                </div>
                            </div>
                </div>
            </div>
        </div>
    </div>
    <?php View::renderTemplate('partials/search', $data); ?>
</div><!-- /.container -->
<?php View::renderTemplate('partials/scripts')?>
<script src="<?=Url::templatePath()?>js/angular/controllers/PmsController.js?<?=VERSIONS_NUMBER?>" type="text/javascript"></script>
<style>
.panel-default{
border-color:#f27331 !important;
border-radius: 10px !important;
}
hr{
    border-top: 1px solid #f27331;
}
</style>

==> patch-2.5.5.3_7_2.zip: app/views/sync/sharedFiles.php <==
<?php use \Core\View;
use Helpers\Auth;
use Helpers\Url;
use Helpers\Form;
use Core\Language;
/*
*
* Copyright 2015
* ParaBlu Systems Private Limited
* All Rights Reserved
*
* NOTICE:  All information contained herein is, and remains
* the property of ParaBlu Systems Private Limited and its suppliers, if any.
* The intellectual and technical concepts contained herein are proprietary
* to ParaBlu Systems Private Limited and its suppliers and may be covered by
* Indian, US and Foreign Patents, patents in process, and are protected by
* trade secret or copyright law.
* Dissemination of this information or reproduction of this material
* is strictly forbidden unless prior written permission is obtained
* from ParaBlu Systems Private Limited.
*
* index.php
*
* @author Naveen Verma - naveenverma@parablu.com
* @version 2..5.5
* @date 17/02/2022
* @time 12:07 PM
*
*/

?>
<div class="container">
    <div class="row">
        <div class="col-lg-6">
            <ol class="breadcrumb">
              <li><h3><?=$data['title']?></h3></li>
                <!--<li><?=$data['crumb1']?></li>-->
            </ol>
        </div>
    </div>
</div>
<div class="main" ng-controller="PmsController">
    <span class="d-none currentPage"><?=''?></span>
    <span class="d-none csrf_token"><?=$data['csrf_token'];?></span>
    <div class="row profile">
        <div class="col-lg-1 col-md-1 col-sm-1">
            <?php View::renderTemplate('partials/sideBar', $data); ?>
        </div>
        <div class="col-lg-11 col-md-11 col-sm-11 ng-cloak">
            <?php if(isMobile()){ ?>
                    <ul class="nav nav-pills flex-column hide" style="border: 1px solid #EC6621;border-radius: 10px;">
                      <li class="nav-item" style="display:unset !important;"><a class="nav-link active" data-toggle="tab" data-target="#filesSharedByMe" aria-expanded="true" aria-controls="filesSharedByMe">Files Shared By Me</a></li>
                      <li class="nav-item" style="display:unset !important;"><a data-toggle="tab" class="nav-link" data-target="#filesSharedWithMe" aria-expanded="false" aria-controls="filesSharedWithMe">Files Shared With Me</a></li>
                    </ul>
            <?php } ?>
            <?php if(!isMobile()){ ?>
                    <ul class="nav nav-tabs hide" role="tablist" style="font-weight: 600;<?php if(!isMobile()){ ?>font-size: medium;<?php }else { ?> font-size: small;<?php } ?>">
                        <li role="presentation" class="nav-item"><a class="nav-link active" data-target="#filesSharedByMe" aria-controls="filesSharedByMe" role="tab" data-toggle="tab">Files Shared By Me</a></li>
                        <li role="presentation" class="nav-item"><a class="nav-link" data-target="#filesSharedWithMe" aria-controls="filesSharedWithMe" role="tab" data-toggle="tab">Files Shared With Me</a></li>
                    </ul>
            <?php } ?>
            <div class="tab-content">
                <div role="tabpanel" class="tab-pane active" id="filesSharedByMe">
                        <div class="row">
                            <div class="panel col-lg-12">
                                <div class="panel-heading hide">
                                    <h4 style="padding: 0px 0px 0px 15px;">Files Shared By Me</h4>
                                </div>
                                <div class="panel-body">
                                 <div class="row">
                                    <div class="col-lg-4">
                                        <div class="panel panel-default no-box-shadow widget-default widget-click">
                                            <!--<div class="panel-header pull-right" style="margin-right: 10px; margin-top: -11px;">
                                                <a class="btn btn-success btn-small hide" ng-click="sendMeTo('/pms/filters')"><i class="fa fa-filter" style="color: white"></i> Filters</a>
                                                <a class="btn btn-success btn-small hide" ng-click="sendMeTo('/pms/schedules')"><i class="fa fa-clock-o" style="color: white"></i> Schedules</a>
                                            </div>
                                            <hr/>-->
                                            <div class="background">
                                                <i class="fa fa-file-o"></i>
                                            </div>
                                            <div class="panel-body widget widget-body clickAble" ng-click="sendMeTo('/share/myShares')">
                                                <i class="fa fa-file-o"></i><span style="font-weight:600;"> Files Shared By Me</span><br/>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col-lg-4">
                                        <div class="panel panel-default no-box-shadow widget-default widget-click">
                                            <!--<div class="panel-header pull-right" style="margin-right: 10px; margin-top: -11px;">
                                                <a class="btn btn-small btn-success pull-right hide" ng-click="sendMeTo('/pms/policyMapping/multiple')">Map policies in bulk</a>
                                            </div>
                                            <hr/>-->
                                            <div class="background">
                                                <i class="fa fa-file-o"></i>
                                            </div>
                                            <div class="panel-body widget widget-body clickAble" ng-click="sendMeTo('/share/filesSharedWithMe')">
                                                <i class="fa fa-file-o"></i><span style="font-weight:600;"> Files Shared With Me</span><br/>
                                            </div>
                                        </div>
                                    </div>
                                </div>
</div>
                            </div>
                        </div>
                </div>
                <div role="tabpanel" class="tab-pane" id="filesSharedWithMe">
                            <div class="row">
                                <div class="panel col-lg-12">
                                    <div class="panel-heading">
                                        <h4 style="padding: 0px 0px 0px 15px;">Files Shared With Me</h4>
                                    </div>
                                    <div class="panel-body">
                                       <div class="row">
                                        <div class="col-lg-4">
                                            <div class="panel panel-default no-box-shadow widget-default widget-click">
                                                <div class="panel-header pull-right" style="margin-right: 10px; margin-top: -11px;">
                                                    <a class="btn btn-success btn-small" ng-click="sendMeTo('/pms/filters')"><i class="fa fa-filter" style="color: white"></i> Filters</a>
                                                    <a class="btn btn-success btn-small d-none" ng-click="sendMeTo('/pms/cloudCredentials')"><i class="fa fa-cloud" style="color: white"></i> Cloud Credentials</a>
                                                </div>
                                                <hr/>
                                                <div class="background">
                                                    <i class="fa fa-file-powerpoint-o"></i>
                                                </div>
                                                <div class="panel-body widget widget-body clickAble" ng-click="sendMeTo('/pms/sync/policies')">
                                                    <?php if(BLUDRIVE_MODE == true){?>
                                                        <i class="fa fa-file-powerpoint-o"> BluDrive Policies</i><br/>
                                                    <a>Create, View, Edit, Clone Policies</a>
                                                    <?php } else {?>
                                                        <i class="fa fa-file-powerpoint-o"> File Sync and Share Policies</i><br/>
                                                                    <a>Create, View, Edit, Clone Policies</a>
                                                    <?php } ?>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-lg-4">
                                            <div class="panel panel-default no-box-shadow widget-default widget-click">
                                                <div class="panel-header pull-right" style="margin-right: 10px; margin-top: -11px;">
                                                    <a class="btn btn-small btn-success pull-right" ng-click="sendMeTo('/pms/sync/policyMapping/multiple')">Map policies in bulk</a>
                                                </div>
                                                <hr/>
                                                <div class="background">
                                                    <i class="fa fa-user"></i>
                                                </div>
                                                <div class="panel-body widget widget-body clickAble" ng-click="sendMeTo('/pms/sync/policyMapping/single')">
                                                    <i class="fa fa-user"> Policy Mapping</i><br/>
                                                    <?php if(BLUDRIVE_MODE == true){?>
                                                    <a>Map users to BluDrive policies</a>
                                                    <?php } else {?>
                                                    <a>Map users to Sync policies</a>
                                                    <?php } ?>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
</div>
                                </div>
                            </div>
                </div>
            </div>
        </div>
    </div>
    <?php View::renderTemplate('partials/search', $data); ?>
</div><!-- /.container -->
<?php View::renderTemplate('partials/scripts')?>
<script src="<?=Url::templatePath()?>js/angular/controllers/PmsController.js" type="text/javascript"></script>
<style>
.panel-default{
border-color:#f27331 !important;
border-radius: 10px !important;
}
hr{
    border-top: 1px solid #f27331;
}
</style>
